@@ -45,7 +45,7 @@ class InvalidOrgMembershipOortCloudError(OortCloudError):
         super().__init__(msg)
 
 
-class InvalidOrganisationTelescopeOortCloudError(OortCloudError):
+class InvalidTelescopeOortCloudError(OortCloudError):
     def __init__(self, telescope_uuid, error_string=''):
         msg = f'Invalid / unknown telescope with UUID {telescope_uuid}.'
         if error_string:
@@ -53,6 +53,14 @@ class InvalidOrganisationTelescopeOortCloudError(OortCloudError):
         super().__init__(msg)
 
 
+class InvalidOrganisationTelescopeOortCloudError(OortCloudError):
+    def __init__(self, telescope_uuid, org_subdomain, error_string=''):
+        msg = f'Telescope with UUID {telescope_uuid} unknown within organisation {org_subdomain}.'
+        if error_string:
+            msg += f'\n{error_string}'
+        super().__init__(msg)
+
+
 class InvalidOrganisationUploadKeyOortCloudError(OortCloudError):
     def __init__(self, subdomain, username, upload_key, error_string=''):
         msg = f'Invalid / unknown upload_key {upload_key} for @{username} and {subdomain} organisation.'
