@@ -3,6 +3,7 @@ import socket
 from typing import Optional
 
 from arcsecond import ArcsecondAPI
+from arcsecond.api.error import ArcsecondRequestTimeoutError
 from peewee import DoesNotExist
 
 from oort import __version__
@@ -57,7 +58,11 @@ class UploadPreparator(object):
     # ------ REMOTE ----------------------------------------------------------------------------------------------------
 
     def _find_remote_resource(self, api: ArcsecondAPI, **kwargs) -> Optional[dict]:
-        response_list, error = api.list(**kwargs)
+        try:
+            response_list, error = api.list(**kwargs)
+        except ArcsecondRequestTimeoutError:
+            # Retrying request in the case of first one timing out.
+            response_list, error = api.list(**kwargs)
 
         # An error occurred. Deal with it.
         if error is not None:
@@ -83,7 +88,11 @@ class UploadPreparator(object):
     def _create_remote_resource(self, api: ArcsecondAPI, **kwargs) -> Optional[dict]:
         self._logger.info(f'{self.log_prefix} Creating remote resource...')
 
-        remote_resource, error = api.create(kwargs)
+        try:
+            remote_resource, error = api.create(kwargs)
+        except ArcsecondRequestTimeoutError:
+            # Retrying request in the case of first one timing out.
+            remote_resource, error = api.create(kwargs)
 
         if error is not None:
             msg = f'Failed to create resource in {api} endpoint: {str(error)}'
@@ -94,7 +103,12 @@ class UploadPreparator(object):
 
     def _update_remote_resource(self, api: ArcsecondAPI, uuid, **kwargs) -> None:
         self._logger.info(f'{self.log_prefix} Updating remote resource...')
-        _, error = api.update(uuid, kwargs)
+        try:
+            _, error = api.update(uuid, kwargs)
+        except ArcsecondRequestTimeoutError:
+            # Retrying request in the case of first one timing out.
+            _, error = api.create(kwargs)
+
         if error is not None:
             self._logger.warn(f'{self.log_prefix} Failed to update remote resource. Ignoring, and moving on.')
         else:
@@ -103,7 +117,7 @@ class UploadPreparator(object):
     # ------ SYNC ------------------------------------------------------------------------------------------------------
 
     def _sync_dataset(self):
-        self._logger.info(f'{self.log_prefix} Syncing DATASET...')
+        self._logger.info(f'{self.log_prefix} Opening sync DATASET sequence...')
         self._pack.upload.smart_update(substatus=Substatus.SYNC_DATASET.value)
 
         # Definition of meaningful tags
@@ -114,13 +128,15 @@ class UploadPreparator(object):
         tag_uploader = f'oort|uploader|{ArcsecondAPI.username()}'
         tag_oort = f'oort|version|{__version__}'
 
-        tags = [tag_folder, tag_root, tag_origin, tag_uploader, tag_oort]
+        search_tags = [tag_folder, tag_root]
+        create_tags = [tag_folder, tag_root, tag_origin, tag_uploader, tag_oort]
         if self._identity.telescope:
-            tags.append(tag_telescope)
+            search_tags.append(tag_telescope)
+            create_tags.append(tag_telescope)
 
         # Kwargs used only for search, then kwargs for create.
-        search_kwargs = {'tags': tag_folder}  # Should we also include telescope?
-        create_kwargs = {'name': self._pack.dataset_name, 'tags': tags}
+        search_kwargs = {'tags': ','.join(search_tags)}
+        create_kwargs = {'name': self._pack.dataset_name, 'tags': create_tags}
 
         # Search for remote resource. If none found, create one.
         datasets_api = ArcsecondAPI.datasets(**self._api_kwargs)
@@ -144,6 +160,7 @@ class UploadPreparator(object):
             self._dataset.smart_update(**dataset_dict)
         # Update Upload model data.
         self._pack.upload.smart_update(dataset=self._dataset)
+        self._logger.info(f'{self.log_prefix} Closing sync DATASET sequence.')
 
     def _sync_telescope(self):
         try:
@@ -159,64 +176,6 @@ class UploadPreparator(object):
         else:
             self._pack.upload.smart_update(telescope=self._telescope)
 
-    # def _sync_night_log(self):
-    #     self._logger.info(f'{self.log_prefix} Syncing NIGHT_LOG...')
-    #     self._pack.upload.smart_update(substatus=Substatus.SYNC_NIGHTLOG.value)
-    #
-    #     # NightLogs are completely determined if they have a date and a telescope.
-    #     # Since a telescope is required for organisation uploads, NightLogs are completely determined
-    #     # for organisations. There will be an ambiguity for personal upload without telescope.
-    #     kwargs = {'date': self._pack.night_log_date_string}
-    #     if self._identity.telescope:
-    #         kwargs.update(telescope=self._identity.telescope)
-    #     else:
-    #         msg = f'{self.log_prefix} No Telescope provided for NightLog {self._pack.night_log_date_string}.'
-    #         self._logger.warn(msg)
-    #
-    #     night_log_api = ArcsecondAPI.nightlogs(**self._api_kwargs)
-    #     night_log_dict = self._find_remote_resource(night_log_api, **kwargs)
-    #     if night_log_dict is None:
-    #         night_log_dict = self._create_remote_resource(night_log_api, **kwargs)
-    #
-    #     try:
-    #         self._night_log = NightLog.get(uuid=night_log_dict['uuid'])
-    #     except DoesNotExist:
-    #         self._night_log = NightLog.create(**night_log_dict)
-    #     else:
-    #         self._night_log.smart_update(**night_log_dict)
-    #
-    # def _sync_observation_or_calibration(self):
-    #     # self._pack.remote_resources_name is either 'observations' or 'calibrations'
-    #     self._logger.info(f'{self.log_prefix} Syncing {self._pack.remote_resources_name[:-1].upper()}...')
-    #     self._pack.upload.smart_update(substatus=Substatus.SYNC_OBS_OR_CALIB.value)
-    #
-    #     search_kwargs = {'night_log': str(self._night_log.uuid),
-    #                      'dataset': str(self._dataset.uuid)}
-    #
-    #     create_kwargs = {'night_log': str(self._night_log.uuid),
-    #                      'dataset': str(self._dataset.uuid),
-    #                      'name': self._pack.clean_folder_name}
-    #
-    #     if self._pack.resource_type == 'observation':
-    #         create_kwargs.update(target_name=self._pack.target_name)
-    #         print(f'\n\n{create_kwargs}\n\n')
-    #
-    #     resources_api = getattr(ArcsecondAPI, self._pack.remote_resources_name)(**self._api_kwargs)
-    #     resource_dict = self._find_remote_resource(resources_api, **search_kwargs)
-    #     if resource_dict is None:
-    #         resource_dict = self._create_remote_resource(resources_api, **create_kwargs)
-    #
-    #     resource_dict.pop('night_log')
-    #     try:
-    #         self._obs_or_calib = self._pack.resource_db_class.get(uuid=resource_dict['uuid'])
-    #     except DoesNotExist:
-    #         self._obs_or_calib = self._pack.resource_db_class.create(**resource_dict)
-    #     else:
-    #         self._obs_or_calib.smart_update(**resource_dict)
-    #     self._obs_or_calib.smart_update(night_log=self._night_log)
-    #
-    #     self._dataset.smart_update(**{self._pack.resource_type: self._obs_or_calib})
-
     def prepare(self):
         self._logger.info(f'{self.log_prefix} Preparation started for {self._pack.final_file_name}')
         self._pack.upload.smart_update(status=Status.PREPARING.value)
